==> react-lds-8.7.0.tgz: package/es/components/ClickOutside/ClickOutside.js <==
import "core-js/modules/es7.symbol.async-iterator";
import "core-js/modules/es6.object.assign";
import "core-js/modules/es6.symbol";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.object.keys";
import "core-js/modules/es6.object.set-prototype-of";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

var ClickOutside =
/*#__PURE__*/
function (_Component) {
  _inherits(ClickOutside, _Component);

  function ClickOutside() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, ClickOutside);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(ClickOutside)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_this), "getContainer", function (ref) {
      _this.container = ref;
    });

    _defineProperty(_assertThisInitialized(_this), "handle", function (e) {
      var onClickOutside = _this.props.onClickOutside;
      var $el = _this.container;

      if (!$el.contains(e.target)) {
        onClickOutside(e);
      }
    });

    _defineProperty(_assertThisInitialized(_this), "handleKeyUp", function (e) {
      var _this$props = _this.props,
          onClickOutside = _this$props.onClickOutside,
          handleEsc = _this$props.handleEsc;

      if (handleEsc && e.key === 'Escape') {
        onClickOutside(e);
        e.stopPropagation();
      }
    });

    return _this;
  }

  _createClass(ClickOutside, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      var condition = this.props.condition;

      if (condition) {
        this.registerEventListener();
      }
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      var condition = this.props.condition;
      var nextCondition = nextProps.condition;

      if (condition !== nextCondition) {
        if (nextCondition) {
          this.registerEventListener();
        } else {
          this.unregisterEventListener();
        }
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.unregisterEventListener();
    }
  }, {
    key: "registerEventListener",
    value: function registerEventListener() {
      var useCapture = this.props.useCapture;
      document.addEventListener('click', this.handle, useCapture);
    }
  }, {
    key: "unregisterEventListener",
    value: function unregisterEventListener() {
      var useCapture = this.props.useCapture;
      document.removeEventListener('click', this.handle, useCapture);
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          children = _this$props2.children,
          condition = _this$props2.condition,
          onClickOutside = _this$props2.onClickOutside,
          useCapture = _this$props2.useCapture,
          handleEsc = _this$props2.handleEsc,
          rest = _objectWithoutProperties(_this$props2, ["children", "condition", "onClickOutside", "useCapture", "handleEsc"]);

      return React.createElement("div", _extends({
        onKeyUp: condition ? this.handleKeyUp : null
      }, rest, {
        ref: this.getContainer
      }), children);
    }
  }]);

  return ClickOutside;
}(Component);

_defineProperty(ClickOutside, "defaultProps", {
  condition: true,
  useCapture: false,
  handleEsc: true
});

export { ClickOutside as default };
ClickOutside.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Nodes that will not trigger the click handler to trigger
   * @type {Node}
   */
  children: PropTypes.node.isRequired,

  /**
  * If true (default) the outside click is registered.
  * Otherwise only the children are rendered
  * @type {Bool}
  */
  condition: PropTypes.bool,

  /**
   * Handler which is being triggered when a click event outside of the
   * children prop is fired
   * @type {Function}
   */
  onClickOutside: PropTypes.func.isRequired,

  /**
   * Will be passed to window.addEventListener,
   * See: https://developer.mozilla.org/en-US/docs/Web/API/EventTarget/addEventListener
   * @type {Bool}
   */
  useCapture: PropTypes.bool,

  /**
   * Handle ESC key press as click outside
   * @type {Bool}
   */
  handleEsc: PropTypes.bool
} : {};

==> react-lds-9.1.0.tgz: package/es/components/ClickOutside/ClickOutside.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.symbol.description";
import "core-js/modules/es.symbol.iterator";
import "core-js/modules/es.array.concat";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.array.iterator";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.get-prototype-of";
import "core-js/modules/es.object.keys";
import "core-js/modules/es.object.set-prototype-of";
import "core-js/modules/es.object.to-string";
import "core-js/modules/es.string.iterator";
import "core-js/modules/web.dom-collections.iterator";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

var ClickOutside =
/*#__PURE__*/
function (_Component) {
  _inherits(ClickOutside, _Component);

  function ClickOutside() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, ClickOutside);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(ClickOutside)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_this), "getContainer", function (ref) {
      _this.container = ref;
    });

    _defineProperty(_assertThisInitialized(_this), "handle", function (e) {
      var onClickOutside = _this.props.onClickOutside;
      var $el = _this.container;

      if (!$el.contains(e.target)) {
        onClickOutside(e);
      }
    });

    _defineProperty(_assertThisInitialized(_this), "handleKeyUp", function (e) {
      var _this$props = _this.props,
          onClickOutside = _this$props.onClickOutside,
          handleEsc = _this$props.handleEsc;

      if (handleEsc && e.key === 'Escape') {
        onClickOutside(e);
        e.stopPropagation();
      }
    });

    return _this;
  }

  _createClass(ClickOutside, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      var condition = this.props.condition;

      if (condition) {
        this.registerEventListener();
      }
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      var condition = this.props.condition;
      var nextCondition = nextProps.condition;

      if (condition !== nextCondition) {
        if (nextCondition) {
          this.registerEventListener();
        } else {
          this.unregisterEventListener();
        }
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.unregisterEventListener();
    }
  }, {
    key: "registerEventListener",
    value: function registerEventListener() {
      var useCapture = this.props.useCapture;
      document.addEventListener('click', this.handle, useCapture);
    }
  }, {
    key: "unregisterEventListener",
    value: function unregisterEventListener() {
      var useCapture = this.props.useCapture;
      document.removeEventListener('click', this.handle, useCapture);
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          children = _this$props2.children,
          condition = _this$props2.condition,
          onClickOutside = _this$props2.onClickOutside,
          useCapture = _this$props2.useCapture,
          handleEsc = _this$props2.handleEsc,
          rest = _objectWithoutProperties(_this$props2, ["children", "condition", "onClickOutside", "useCapture", "handleEsc"]);

      return React.createElement("div", _extends({
        onKeyUp: condition ? this.handleKeyUp : null
      }, rest, {
        ref: this.getContainer
      }), children);
    }
  }]);

  return ClickOutside;
}(Component);

_defineProperty(ClickOutside, "defaultProps", {
  condition: true,
  useCapture: false,
  handleEsc: true
});

export { ClickOutside as default };
ClickOutside.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Nodes that will not trigger the click handler to trigger
   * @type {Node}
   */
  children: PropTypes.node.isRequired,

  /**
  * If true (default) the outside click is registered.
  * Otherwise only the children are rendered
  * @type {Bool}
  */
  condition: PropTypes.bool,

  /**
   * Handler which is being triggered when a click event outside of the
   * children prop is fired
   * @type {Function}
   */
  onClickOutside: PropTypes.func.isRequired,

  /**
   * Will be passed to window.addEventListener,
   * See: https://developer.mozilla.org/en-US/docs/Web/API/EventTarget/addEventListener
   * @type {Bool}
   */
  useCapture: PropTypes.bool,

  /**
   * Handle ESC key press as click outside
   * @type {Bool}
   */
  handleEsc: PropTypes.bool
} : {};
